size property
The child widget size is required to use with GestureDetector in the child tree.
Notice: this widget builds Positioned with zero size to center the child at alignment on the parent widget but gesture detection such as GestureDetector won't work with zero size.
Implementation
final Size size;